huhu
===================
simple scripting language & simple interpreter for kids education

## * This Project Under Development *

### Installation

> wget https://raw.githubusercontent.com/huhu-project/huhu_lang/master/huhu

> sudo ln -s /usr/bin/huhu ./huhu

> rm ./huhu

### Syntax

This language purposes only to get rid of the complexity and keep It simple development training.

```sh

* set
değişken = bu bir değişken

* list
liste = bu, bir, liste

* write
yaz(değişken)

* looping
yaz(kelime dön kelimeler)

* range
sayilar = 1..8
yaz(sayi) dön sayilar

harfler = a..z
yaz(harf) dön harfler

```
if you have any clean syntax idea, please create an issue for discussion.
